@@ -1,6 +1,6 @@
 package App::Oozie::Util::Misc;
-$App::Oozie::Util::Misc::VERSION = '0.009';
-use 5.010;
+$App::Oozie::Util::Misc::VERSION = '0.010';
+use 5.014;
 use strict;
 use warnings;
 use parent qw( Exporter );
@@ -10,7 +10,11 @@ our @EXPORT_OK = qw(
     resolve_tmp_dir
 );
 
-sub remove_newline { my $s = shift; $s =~ s{\n+}{ }xmsg; $s }
+sub remove_newline {
+    my $s = shift;
+    $s =~ s{\n+}{ }xmsg;
+    return $s;
+}
 
 sub resolve_tmp_dir {
     # Wokaround "/tmp is an existing symbolic link" error.
@@ -36,7 +40,7 @@ App::Oozie::Util::Misc
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
